var USRApp = USRApp || {
    // Accepted media type details
    mediaDetails: {
        "aip-media-type-youtube": ["video", "youtube"],
        "aip-media-type-vimeo": ["video", "vimeo"],
        "aip-media-type-mp4": ["video", "video/mp4"],
        "aip-media-type-m4v": ["video", "video/mp4"],
        "aip-media-type-f4v": ["video", "video/mp4"],
        "aip-media-type-mov": ["video", "video/mp4"],
        "aip-media-type-flv": ["video", "video/flv"],
        "aip-media-type-webm": ["video", "video/webm"],
        "aip-media-type-aac": ["audio", "audio/mp4"],
        "aip-media-type-m4a": ["audio", "audio/mp4"],
        "aip-media-type-f4a": ["audio", "audio/mp4"],
        "aip-media-type-mp3": ["audio", "audio/mpeg"],
        "aip-media-type-ogg": ["audio", "audio/ogg"]
    },
    dialogHeights: {
        standardSize: "315",
        smallSize: "188",
        fullSize: "510"
    },
    dialogWidths: {
        standardSize: "420",
        smallSize: "250",
        fullSize: "680"
    },
    /**
     * Define video/audio details by class 
     */
    aipCreateMediaTags: function() {
        var count = 0;

        $("div.aip-embed-media").each(function (index) {
            var aipMediaCode = "",
                aipMedia = $(this),
                mediaSrc = aipMedia.text(),
                mediaWidth = USRApp.dialogWidths.standardSize,
                mediaHeight = USRApp.dialogHeights.standardSize,
                mimeType = "",
                fileType = "",
                playerId = "",
                classAlignment = "";

            // remove spaces if they occur within the source
            mediaSrc = mediaSrc.replace(/\s+/g, "");
            // alignment set through css default is left
            if (aipMedia.hasClass("aip-media-align-right")) {
                classAlignment = "aip-media-align-right";
            } else if (aipMedia.hasClass("aip-media-align-center")) {
                classAlignment = "aip-media-align-center";
            }
            // get size requirement
            if (aipMedia.hasClass("aip-media-size-small")) {
                mediaWidth = USRApp.dialogWidths.smallSize;
                mediaHeight = USRApp.dialogHeights.smallSize;
            } else if (aipMedia.hasClass("aip-media-size-full")) {
                mediaWidth = USRApp.dialogWidths.fullSize;
                mediaHeight = USRApp.dialogHeights.fullSize;
            }
            // checks classes to determine mime type and file type
            for (var key in USRApp.mediaDetails) {
                if (aipMedia.hasClass(key)) {
                    fileType = USRApp.mediaDetails[key][0];
                    mimeType = USRApp.mediaDetails[key][1];
                }
            }
            // if blank send warning
            if (fileType === "") {
                // non-accepted media type array insert after media info div
                if (!aipMedia.next().is("#mediaEmbedCode")) {
                    $("<div id='mediaEmbedCode'><a href='" + mediaSrc + "' title='Link to video'>" + mediaSrc + "</a></div>").insertAfter(this);
                } else {
                    aipMedia.next().html("<a href='" + mediaSrc + "' title='Link to video'>" + mediaSrc + "</a>");
                }
            }
            // else set it up
            if (fileType !== "" && mimeType !== "") {
                if (mimeType === "youtube") {
                    aipMediaCode = "<iframe src='" + mediaSrc + 
                                   "'width='" + mediaWidth + 
                                   "' height='" + mediaHeight + 
                                   "' frameborder='0' allowfullscreen></iframe>";

                    // insert after media info div
                    if (!aipMedia.next().is("#mediaEmbedCode")) {
                        $("<div id='mediaEmbedCode'>" + aipMediaCode + "</div>").insertAfter(this);
                    } else {
                        aipMedia.next().html(aipMediaCode);
                    }
                } else if (mimeType === "vimeo") {
                    aipMediaCode = "<iframe src='" + mediaSrc + 
                                   "' width='" + mediaWidth + 
                                   "' height='" + mediaHeight + 
                                   "' frameborder='0' webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>";

                    // insert after media info div
                    if (!aipMedia.next().is("#mediaEmbedCode")) {
                        $("<div id='mediaEmbedCode'>" + aipMediaCode + "</div>").insertAfter(this);
                    } else {
                        aipMedia.next().html(aipMediaCode);
                    }
                } else { //use JW player
                    playerId = "mediaEmbedCode" + count;
                    aipMediaCode = "<div id='" + playerId + "'></div>";
                    // insert after media info div
                    if (!aipMedia.next().is("#mediaEmbedCode")) {
                        $(aipMediaCode).insertAfter(this);
                    } else {
                        aipMedia.next().html(aipMediaCode);
                    }
                    count += 1;
                    jwplayer(playerId).setup({
                        file: mediaSrc,
                        width: mediaWidth,
                        height: mediaHeight,
                        fallback: false
                    });
                }
                // changes alignment if this is set
                if (classAlignment !== "") {
                    aipMedia.next("div[id^='mediaEmbedCode']").addClass(classAlignment);
                }
            }
        }); //end for each
    }
};

$(document).ready(function() {
    // if this div exists create embed tag
    if ($("div.aip-embed-media").length) {
        USRApp.aipCreateMediaTags();
    }
    // whenever you edit, remove the media embed tag
    $("span.blurb-editor").click(function(e) {
        $("div[id^='mediaEmbedCode']").each(function(index) {
            $(this).remove();
        });
    });

    $(".aip-left-side-linkset li").click(function(e) {
        var $this = $(this),
            idName;
        if ($this.find("a").hasClass("aip-externaltab")) {
            return true;
        } else {
            if ($("#aip-linked-content-parts").length) {
                idName = $this.attr("id");
                $("#aip-linked-content-parts").find(".aip-linked-content-part").each(function(index) {
                    var $thisItem = $(this);
                    if ($thisItem.hasClass(idName)) {
                        $thisItem.show();
                    } else {
                        $thisItem.hide();
                    }
                });
                return false;
            } else {
                return true;
            }
        }
    });
    // Allow users to define external links
    // temporarily adding the email this link to this function until we can get dialog up
    $(".aip-user-externallink, span.emailtext a").live("click", function(e) {
        var target = $(this).attr("href");
        window.open(target);
        return false;
    });
    return false;
});
